pub type Condition = u8;
Condition: the argument given to Cmov and CmovEq representing an effective boolean condition by virtue of being zero or non-zero.
Cmov
CmovEq
Using a u8 for this type helps prevent rustc optimizers from speculating about it as if it were a boolean value.
u8